##  Inclusion of Fact Sheets for Calculation
In the obsolescence risk management dashboard, the following fact sheets are excluded from the calculations of KPIs related to obsolescence risk:
  * Applications with the End of life lifecycle phase
  * Fact sheets with the Draft or Rejected quality seal


However, IT component fact sheets with the End of life state are included in KPI calculations as active applications might still be using them.
